@@ -1,4 +1,4 @@
-use poem::{Error, FromRequest, IntoResponse, Request, RequestBody, Response};
+use poem::{http::StatusCode, FromRequest, IntoResponse, Request, RequestBody, Response};
 use serde_json::Value;
 
 use crate::{
@@ -33,16 +33,14 @@ impl<T: ParseFromJSON> ParsePayload for Json<T> {
     ) -> Result<Self, ParseRequestError> {
         let value = poem::web::Json::<Value>::from_request(request, body)
             .await
-            .map_err(|err| ParseRequestError::ParseRequestBody {
-                reason: Into::<Error>::into(err)
-                    .reason()
-                    .unwrap_or_default()
-                    .to_string(),
-            })?;
-        let value =
-            T::parse_from_json(value.0).map_err(|err| ParseRequestError::ParseRequestBody {
-                reason: err.into_message(),
-            })?;
+            .map_err(|err| ParseRequestError::ParseRequestBody(err.into_response()))?;
+        let value = T::parse_from_json(value.0).map_err(|err| {
+            ParseRequestError::ParseRequestBody(
+                Response::builder()
+                    .status(StatusCode::BAD_REQUEST)
+                    .body(err.into_message()),
+            )
+        })?;
         Ok(Self(value))
     }
 }
